#!/bin/sh
QPKG_NAME=xCloud
SERVER_DIR=
SERVER_VERSION=
CPU_INFO_LOG=
SYS_INFO_LOG=
MEM_INFO_LOG=
NETWORD_INFO_LOG=
LINK_INFO_LOG=
PING_INFO_LOG=
XCLOUD_INFO_LOG=
WEB_DIR=
find_base() {
        if [ -f /etc/config/smb.conf ]; then
                BASE=""
                DEV_DIR="HDA HDB HDC HDD HDE HDF HDG HDH MD0 MD1 MD2 MD3"
                publicdir=`/sbin/getcfg Public path -f /etc/config/smb.conf`
                if [ ! -z $publicdir ] && [ -d $publicdir ];then
                        BASE=`echo $publicdir |awk -F/Public '{ print $1 }'`
                else
                        for datadirtest in $DEV_DIR; do
                                [ -d /share/${datadirtest}_DATA/Public ] && BASE=/share/${datadirtest}_DATA
                        done
                fi
                if [ -z $BASE ]; then
                        echo "The base directory cannot be found."
                        exit 1
                else
                        SERVER_DIR=${BASE}/.qpkg/${QPKG_NAME}
                fi
		DEF_SHARECONF="/etc/config/def_share.info"
		WEB=$(/sbin/getcfg -c SHARE_DEF defWeb -f $DEF_SHARECONF)
		WEB_DIR=${BASE}/$WEB/${QPKG_NAME}
                SERVER_VERSION="QNAP"
		CPU_INFO_LOG=$SERVER_DIR/log/cpu.log
		SYS_INFO_LOG=$SERVER_DIR/log/sys.log
		MEM_INFO_LOG=$SERVER_DIR/log/mem.log
		NETWORD_INFO_LOG=$SERVER_DIR/log/network.log
		LINK_INFO_LOG=$SERVER_DIR/log/link.log
		PING_INFO_LOG=$SERVER_DIR/log/ping.log
		XCLOUD_INFO_LOG=$SERVER_DIR/log/xcloud.log
        elif [ -f /usr/syno/etc/smb.conf ]; then
                SERVER_DIR="/usr/local/xcloud"
		WEB=`/usr/syno/sbin/synoshare --get web|grep Path|awk -F[ '{print $2}' | awk -F] '{print $1}'`
		WEB_DIR=$WEB/${QPKG_NAME}
                SERVER_VERSION="SYNOLOGY"
                CPU_INFO_LOG=$SERVER_DIR/log/cpu.log
                SYS_INFO_LOG=$SERVER_DIR/log/sys.log
                MEM_INFO_LOG=$SERVER_DIR/log/mem.log
                NETWORD_INFO_LOG=$SERVER_DIR/log/network.log
                LINK_INFO_LOG=$SERVER_DIR/log/link.log
                PING_INFO_LOG=$SERVER_DIR/log/ping.log
                XCLOUD_INFO_LOG=$SERVER_DIR/log/xcloud.log
        fi
}

collect_cpu_info() {
	echo "cpu_info:" > $CPU_INFO_LOG
	cat /proc/cpuinfo >> $CPU_INFO_LOG
}
collect_sys_info() {
	echo "sys_info:" > $SYS_INFO_LOG
	uname -a >> $SYS_INFO_LOG
}
collect_mem_info() {
	echo "mem_info:" > $MEM_INFO_LOG
	top >> $MEM_INFO_LOG &
	sleep 10
        for TOP_ID in $(ps|grep "top"|grep -v grep|awk '{print $1}')
        do
                kill -9 $TOP_ID
        done
}
collect_network_info() {
	echo "network_info:" > $NETWORD_INFO_LOG
	ifconfig -a >> $NETWORD_INFO_LOG
	
}
collect_link_info() {
	echo "link_info:" > $LINK_INFO_LOG
	netstat -an >> $LINK_INFO_LOG 2>&1
}
collect_ping_info() {
	echo "ping_info:" > $PING_INFO_LOG
	ping xcloud.cc >> $PING_INFO_LOG &
	sleep 20
	for PING_ID in $(ps|grep "ping xcloud.cc"|grep -v grep|awk '{print $1}')
	do
		kill -9 $PING_ID
	done
}
collect_xcloud_info() {
	echo "xcloud_config_info:" > $XCLOUD_INFO_LOG
	cat $SERVER_DIR/etc/.share.conf >> $XCLOUD_INFO_LOG
}
collect_all_log() {
	local FILE_NAME=$(date +%Y%m%d_%H%M%S)
	cd $SERVER_DIR/log
	tar cf ${FILE_NAME}.tar.gz *
	if [ ! -d $WEB_DIR/log ]
	then
		mkdir -p $WEB_DIR/log
	fi
	mv ${FILE_NAME}.tar.gz $WEB_DIR/log/
}
main() {
	find_base
	collect_cpu_info
	collect_sys_info
	collect_mem_info
	collect_network_info
	collect_link_info
	collect_ping_info
	collect_xcloud_info
	collect_all_log
}
main $@
